@@ -5,7 +5,7 @@
 // <Ilya.Skriblovsky@gmail.com>
 //
 
-// $Id: Main.cpp 95 2010-06-14 08:57:20Z mitrandir $
+// $Id: Main.cpp 108 2010-07-07 13:23:53Z mitrandir $
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -16,9 +16,12 @@
 #include "XTools.h"
 #include "Settings.h"
 #include "Resources.h"
+#include "DBus.h"
 
 int main(int argc, char *argv[])
 {
+    XInitThreads();
+
     Settings settings;
 
     Display *dpy = XOpenDisplay(0);
@@ -50,8 +53,17 @@ int main(int argc, char *argv[])
     TeleWindow *window = new TeleWindow(dpy);
     //window->show();
 
+#ifdef DBUS
+    DBus *dbus = new DBus(window);
+    dbus->startMainLoop();
+#endif
+
     window->eventLoop();
 
+#ifdef DBUS
+    delete dbus;
+#endif
+
     delete window;
 
     XCloseDisplay(dpy);
