@@ -5,7 +5,7 @@
 // <Ilya.Skriblovsky@gmail.com>
 //
 
-// $Id: TeleWindow.cpp 105 2010-07-06 10:59:53Z mitrandir $
+// $Id: TeleWindow.cpp 115 2010-07-14 09:52:24Z mitrandir $
 
 #include "TeleWindow.h"
 
@@ -198,15 +198,18 @@ void TeleWindow::show()
     // Hack for Nokia's builtin mediaplayer that leaves it's
     // video overlay on screen after task switching when
     // Composite is enables
-    if (_activeThumbnail && _activeThumbnail->isOssoMediaPlayer())
+    if (_activeThumbnail)
     {
-        paint();
-        XSync(_dpy, 0);
-        struct timeval timeout;
-        timeout.tv_sec = 0;
-        timeout.tv_usec = 100000;
-        select(0, 0, 0, 0, &timeout);
-        _activeThumbnail->minimize();
+        if (_activeThumbnail->mustBeIconifiedBeforeTelescope())
+        {
+            paint();
+            XSync(_dpy, 0);
+            struct timeval timeout;
+            timeout.tv_sec = 0;
+            timeout.tv_usec = 100000;
+            select(0, 0, 0, 0, &timeout);
+            _activeThumbnail->minimize();
+        }
     }
 #endif
 
@@ -396,6 +399,7 @@ void TeleWindow::eventLoop()
 {
     XEvent event;
 
+    XLockDisplay(_dpy);
 
     XGrabKey(_dpy, _hotKeyCode, 0, _rootWindow, False, GrabModeAsync, GrabModeAsync);
 
@@ -404,8 +408,12 @@ void TeleWindow::eventLoop()
     {
         do
         {
+            XUnlockDisplay(_dpy);
+
             XNextEvent(_dpy, &event);
 
+            XLockDisplay(_dpy);
+
             if (event.xany.window == _rootWindow)
             {
                 onRootEvent(&event);
@@ -448,6 +456,8 @@ void TeleWindow::eventLoop()
     }
 
     XUngrabKey(_dpy, _hotKeyCode, AnyModifier, _rootWindow);
+
+    XUnlockDisplay(_dpy);
 }
 
 
@@ -456,7 +466,7 @@ void TeleWindow::onRootEvent(XEvent *event)
 {
     if (event->type == KeyPress && event->xkey.keycode == _hotKeyCode)
         onHotKeyPress();
-    if (event->type == KeyRelease && event->xkey.keycode == _hotKeyCode)
+    else if (event->type == KeyRelease && event->xkey.keycode == _hotKeyCode)
         onHotKeyRelease();
 //    else if (event->type == MapNotify)
 //    {
