@@ -5,7 +5,7 @@
 // <Ilya.Skriblovsky@gmail.com>
 //
 
-// $Id: Thumbnail.h 99 2010-06-22 05:08:36Z mitrandir $
+// $Id: Thumbnail.h 111 2010-07-09 11:48:29Z mitrandir $
 
 // Thumbnail - represents single window preview
 
@@ -63,6 +63,7 @@ class Thumbnail
 
 #ifdef MAEMO4
         bool _isOssoMediaPlayer;
+        bool _isLiqBase;
 #endif
 
 
@@ -105,8 +106,11 @@ class Thumbnail
 
 #ifdef MAEMO4
         bool isOssoMediaPlayer() { return _isOssoMediaPlayer; }
+        bool isLiqBase() { return _isLiqBase; }
 #endif
 
+        bool mustBeIconifiedBeforeTelescope();
+
         void onClientEvent(XEvent *event);
 
 
